<?php

/*********************************************************************************

 * The contents of this file are subject to the SugarCRM Public License Version 1.1.2

 * ("License"); You may not use this file except in compliance with the

 * License. You may obtain a copy of the License at http://www.sugarcrm.com/SPL

 * Software distributed under the License is distributed on an  "AS IS"  basis,

 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License for

 * the specific language governing rights and limitations under the License.

 * The Original Code is:  SugarCRM Open Source

 * The Initial Developer of the Original Code is SugarCRM, Inc.

 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.;

 * All Rights Reserved.

 * Contributor(s): ______________________________________.

 ********************************************************************************/

/*********************************************************************************

 * $Header: /advent/projects/custprojects/vtigercrm/vtigersupport/vtiger_crm/modules/Settings/language/en_us.lang.php,v 1.2 2007/07/06 09:55:40 rajeshkannan Exp $

 * Description:  Defines the English language pack for Settings

 * Portions created by SugarCRM are Copyright (C) SugarCRM, Inc.

 * All Rights Reserved.

 * Contributor(s): Valmir Carlos Trindade/Translate to Brazilian Portuguese| 03/03/2012 |Curitiba/Paraná/Brasil.|www.ttcasolucoes.com.br

 ********************************************************************************/



$mod_strings = Array(

'LBL_MODULE_NAME'=>'Configurações',

'LBL_MODULE_TITLE'=>'Configurações: Principal',

'LBL_LIST_CONTACT_ROLE'=>'Função',



'LBL_LIST_LAST_NAME'=>'Sobrenome',

'LBL_FIRST_NAME'=>'Nome:',

'LBL_LAST_NAME'=>'Sobrenome:',

'LBL_PHONE'=>'Fone:',

'LBL_EMAIL_ADDRESS'=>'E-mail',

'LBL_TRANSCURR'=>'Transferir Moeda Usuário para',

'LBL_CURRDEL'=>'Moeda a ser Apagada',

'LBL_NEW_FORM_TITLE'=>'Novo Contato',

'LBL_NEW_CURRENCY'=>'Nova Moeda',

'LBL_VIEWING'=>'Visualizar',

'LBL_CURRENCY_NAME'=>'Nome Moeda',

'LBL_CURRENCY_CODE'=>'Código Moeda',

'LBL_CURRENCY_SYMBOL'=>'Símbolo',

'LBL_CURRENCY_CRATE'=>'Taxa Câmbio',

'LBL_CURRENCY_STATUS'=>'Status',

'LBL_CURRENCY_TOOL'=>'Ferramentas',

'LBL_CURRENCY_LIST'=>'Lista Moedas',


'NTC_DELETE_CONFIRMATION'=>'Tem certeza que deseja deletar este registro?',

'LEADCUSTOMFIELDS'=>'Campos Customizados Lead',

'ACCOUNTCUSTOMFIELDS'=>'Campos Organização Customizados',

'CONTACTCUSTOMFIELDS'=>'Campos Customizados Contato',

'OPPORTUNITYCUSTOMFIELDS'=>'Campos Customizados Oportunidade',

'HELPDESKCUSTOMFIELDS'=>'Campos Customizados Helpdesk',

'PRODUCTCUSTOMFIELDS'=>'Campos Customizados Produto',

'VENDORCUSTOMFIELDS'=>'Campos Customizados Fornecedor',

'PRICEBOOKCUSTOMFIELDS'=>'Campos Customizados Lista Preços',

'POCUSTOMFIELDS'=>'Campos Customizados Pedido Compra',
'SOCUSTOMFIELDS'=>'Campos Customizados Pedido Vendas',
'QUOTESCUSTOMFIELDS'=>'Campos Customizados Cotações',
'INVOICECUSTOMFIELDS'=>'Campos Customizados Fatura',

'EDITLEADPICKLISTVALUES'=>'Editar Lista Opções Lead ',

'EDITACCOUNTPICKLISTVALUES'=>'Editar Lista Opções Organização ',

'EDITCONTACTPICKLISTVALUES'=>'Editar Lista Opções Contato ',

'EDITOPPORTUNITYPICKLISTVALUES'=>'Editar Lista Opções Oportunidade ',

'EDITHELPDESKPICKLISTVALUES'=>'Editar Lista Opções HeldDesk ',

'EDITPRODUCTPICKLISTVALUES'=>'Editar Lista Opções Produto ',

'EDITEVENTPICKLISTVALUES'=>'Editar Lista Opções Evento ',

'EDITTASKPICKLISTVALUES'=>'Editar Lista Opções Tarefa ',

'EDITRSSPICKLISTVALUES'=>'Editar Lista Opções RSS',
'EDITVENDORPICKLISTVALUES'=>'Editar Lista Opções Fornecedor',
'EDITPBPICKLISTVALUES'=>'Editar Lista Opções Lista Preços',
'EDITPOPICKLISTVALUES'=>'Edita Lista Opções Pedido Compras',
'EDITSOPICKLISTVALUES'=>'Edita Lista Opções Pedido Vendas',
'EDITQUOTEPICKLISTVALUES'=>'Edita Lista Opções Cotação',
'EDITINVOICEPICKLISTVALUES'=>'Edita Lista Opções Fatura',


// Added for Release vtigerCRM 3.2 PATCH 1.0

//Settings/index.php


'LBL_PICKLIST_FIELD_SETTINGS'=>'Configurações Campos Lista de Opções:',



//SETTINGS/CustomFieldList.php,ComboFieldList.php,CreateCustomField.php

'Leads'=>'Lead',

'Accounts'=>'Organização',

'Contacts'=>'Contato',

'Potentials'=>'Oportunidade',

'HelpDesk'=>'HelpDesk',

'Products'=>'Produto',

'Events'=>'Evento',

'Activities'=>'Tarefa',

'CustomFields'=>'Campos Customizados',

'NewCustomField'=>'Novo Campo Customizado',

'NewCustomFieldAltC'=>'Novo Campo Customizado [Alt+c]:',

'FieldName'=>'Nome Campo',

'FieldType'=>'Tipo Campo',

'FieldLabel'=>'Rótulo Campo',

'Delete'=>'Apagar',

'NEW'=>'Novo',

'CUSTOMFIELD'=>'Campo Customizado',

'LBL_CUSTOM_FIELDS'=>'Customizar Campos',

'LBL_ADD_FIELD'=>'Adicionar Campo',

'LBL_CUSTM_MSG'=>'permite-lhe....',

'PicklistFields'=>'Campos Lista Opções',


'Edit'=>'Editar',

'LBL_EDIT_FIELD_TYPE'=>'Editar Tipo Campo',

//Settings/CustomField.html

'LBL_PROVIDE_FIELD_INFORMATION'=>'Forneça Informação do Campo:',

'LBL_SELECT_FIELD_TYPE'=>'Selecione Tipo Campo: ',

'LBL_PROVIDE_FIELD_DETAILS'=>'Forneça Detalhes Campo: ',

'LBL_LABEL'=>'Rótulo: ',

'LBL_LENGTH'=>'Tamanho: ',

'LBL_DECIMAL_PLACES'=>'Casas Decimais: ',

'LBL_PICK_LIST_VALUES'=>'Valores Lista Opções: ',



//Settings/EditComboField.php

'EditPickListValues'=>'Editar Lista Opções ',



//Settings/EditField.html

'LBL_FIELD_INFORMATION'=>'Informação do Campo:',

'Values'=>'Valores',

'EnterListOfValues'=>'Por favor, insira a lista de valores abaixo. Um valor por linha.',



//Settings/fieldtypes.php

'Text'=>'Texto',

'Number'=>'Número',

'Percent'=>'Percentual',

'Currency'=>'Moeda',

'Date'=>'Data',

'Email'=>'E-mail',

'Phone'=>'Fone',

'PickList'=>'Lista de Opções',

'LBL_MULTISELECT_COMBO'=>'Caixa Combinação Multi-Seleção',

'Skype'=>'Skype',

'Time'=>'Hora',

//added for patch2

'USERGROUPLIST'=>'Grupos',

'EMAILTEMPLATES'=>'Modelos E-mail',

'WORDINTEGRATION'=>'Mesclar Modelos Correspondências',

'LBL_MAIL_MERGE'=>'Mesclar Correspondência',

'NOTIFICATIONSCHEDULERS'=>'Sistema Agendamento Notificação',
//currency status
'LBL_ACTIVE'=>'Ativo',

'LBL_INACTIVE'=>'Inativo',

'LBL_NOTIFICATION'=>'Notificação',
'LBL_DESCRIPTION'=>'Descrição',
'LBL_TOOL'=>'Ferramenta',


//Added fields for Title Informations -- after 4 Beta

'LBL_EMAIL_CONFIG'=>'Configuração Servidor Envio Mensagem',

'LBL_WORD_INTEGRATION'=>'Integraçào com MS Word:',

'LBL_GROUP_SETTINGS'=>'Configuração de Grupos:',

'LBL_TEMPLATE_SETTINGS'=>'Configuração de Modelos:',

'LBL_NOTIFICATION_SETTINGS'=>'Configuração de Notificações:',

'LBL_EMAIL_SETTINGS'=>'Configuração de E-mails:',

'LBL_SECURITY_SETTINGS'=>'Configuração de Segurança:',



//Added fields after RC1 - Release

'LBL_MAIL_SERVER_INFO'=>'Informação Servidor Envio Mensagem',

'LBL_OUTGOING_MAIL_SERVER'=>'Nome Servidor',

'LBL_OUTGOING_MAIL_SERVER_LOGIN_USER_NAME'=>'Login do Usuário no Servidor de Envio Mensagem',

'LBL_OUTGOING_MAIL_SERVER_PASSWORD'=>'Senha Servidor Envio Mensagem',

'LBL_MAIL_SERVER_SMTP'=>'Configurações Servidor Mensagem (SMTP)',

'LBL_BACKUP_SERVER_CONFIG'=>'Configuração Servidor de Backup',

'LBL_SERVER_ADDRESS'=>'Endereço Servidor',

'LBL_FTP_SERVER_NAME'=>'Nome Servidor FTP',

'LBL_FTP_USER_NAME'=>'Nome Usuário FTP',

'LBL_FTP_PASSWORD'=>'Senha FTP',

'LBL_FTP'=>'FTP',

'LBL_SYSTEM_CONFIG'=>'Configuração do Sistema',
'LBL_SYSTEM_INFO'=>'Informação Sistema',
'LBL_PROXY_SETTINGS'=>'Servidor Proxy',
'LBL_AUDIT_TRAIL'=>'Informação Auditoria',
'LBL_ENABLE_AUDIT_TRAIL'=>'Habilitar Auditoria',
'LBL_USER_AUDIT'=>'Selecionar Usuário',
'LBL_VIEW_AUDIT_TRAIL'=>'Visualizar Auditoria',
'LBL_AUDIT_TRAIL_DESC'=>'Tela de Auditoria de Usuários que acessam o CRM',
'LBL_NO_DATA'=>'Nenhum Dado',

'LBL_CURRENCY_CONFIGURATION'=>'- Informação da Moeda',

'LBL_CURRENCY_CONFIG'=>'Configuração da Moeda',

'LBL_CURRENCY_INFO'=>'Informação da Moeda',

'LBL_CURRENCY_TITLE'=>'Moeda',

'LBL_CURRENCY_SETTINGS'=>'Moedas',


'LBL_USERNAME'=>'Nome Usuário',
'LBL_PASWRD'=>'Senha',
'LBL_REQUIRES_AUTHENT'=>'Requer Autenticação?',
'LBL_FROM_EMAIL_FIELD'=>'Do Email',

//Fields for Settings

'LBL_USER_MANAGEMENT'=>'Administração de Usuário & Acessos',

'LBL_USERS'=>'Usuários',

'LBL_USERS_LIST'=>'Lista Usuários',
'LBL_GROUP_LIST'=>'Lista Grupos',

'LBL_CREATE_AND_MANAGE_USERS'=>'- Criar e Administrar Usuários (ex., admin)',


'LBL_CREATE_AND_MANAGE_USER_ROLES'=>'- Criar e Administrar Funções de Usuário (ex., Administrador, Usuário Padrão, etc.)',

'LBL_PROFILES'=>'Perfis',

'LBL_PROFILES_LIST'=>'Lista Perfis',

'LBL_CREATE_AND_MANAGE_USER_PROFILES'=>'- Criar e Administrar Perfis de Usuários (ex., CEO, Gerente de Vendas, etc.)',

'LBL_CREATE_AND_MANAGE_USER_GROUPS'=>'- Criar e Administrar Grupos de Usuários',

'LBL_SHARING_ACCESS'=>'Compartilhar Acesso',

'LBL_FIELDS_ACCESS'=>'Acesso Campos',

'LBL_DEFAULT_ORGANIZATION_FIELDS'=>'Padrão Acesso Campos Organização',

'LBL_SETTING_DEFAULT_ORGANIZATION_FIELDS'=>' - Configurar Padrão Acesso Campos na Organização',

'LBL_SETTING_DEFAULT_SHARING_ACCESS'=>'- Configurar Padrão Acesso Compartilhado na Organização',

'LBL_FIELD_ACCESSIBILITY'=>'Acessibilidade aos Campos',

'LBL_SETTING_FIELD_ACCESSIBILITY'=>' - Configurar Acessibilidade Campos para cada Perfil',
//<<<<<<<<for edit ordering blocks>>>>>>
'LBL_FIELD_ORDERING_DESC'=>' - Editar Ordem do Campo',

'LBL_FIELD_ORDERING'=>'Editar Blocos do Campo',
//<<<<<<<<<<end>>>>>>>>>>>>>
'LBL_LEAD_FIELD_ACCESS'=>'Acesso Campo Lead',

'LBL_ACCOUNT_FIELD_ACCESS'=>'Acesso Campo Organização',

'LBL_CONTACT_FIELD_ACCESS'=>'Acesso Campo Contato',

'LBL_OPPORTUNITY_FIELD_ACCESS'=>'Acesso Campo Oportunidade',

'LBL_HELPDESK_FIELD_ACCESS'=>'Acesso Campo HelpDesk',

'LBL_PRODUCT_FIELD_ACCESS'=>'Acesso Campo Produto',

'LBL_NOTE_FIELD_ACCESS'=>'Acesso Campo Documento',

'LBL_EMAIL_FIELD_ACCESS'=>'Acesso Campo E-mail',

'LBL_TASK_FIELD_ACCESS'=>'Acesso Campo Tarefa',

'LBL_EVENT_FIELD_ACCESS'=>'Acesso Campo Evento',

'LBL_DELETE_DEMO_DATA'=>'Apagar Dados de Demonstração',

'LBL_DELETE_DEMO_DATA_INFO'=>'- Apagar os dados de Demonstração criados durante a instalação',



'LBL_STUDIO'=>'Estudio',

'LBL_CUSTOM_FIELD_SETTINGS'=>'Configurações Campo Customizado',

'LBL_CREATE_AND_MANAGE_USER_DEFINED_FIELDS'=>'Administrar campos customizados para sua Empresa',

'LBL_SELECT_MODULE'=>'Selecionar Módulo',

'LBL_SELECT_CF_TEXT'=>'<b>Selecionar Módulo:</b>',



'LBL_PICKLIST_SETTINGS'=>'Configuração Lista de Opções',

'LBL_EDIT_PICKLIST_VALUES'=>' - Editar valores dos Campos da Lista de Opções',

'LBL_EDIT'=>'Editando',

'LBL_COMMUNICATION_TEMPLATES'=>'Modelos de Comunicação',

'LBL_CREATE_EMAIL_TEMPLATES'=>'Novo Modelo de E-mail',

'LBL_UPLOAD_MSWORD_TEMPLATES'=>' - Transferir Modelos do MS Word para Mesclar Correspondência',

'LBL_SCHEDULE_EMAIL_NOTIFICATION'=>' - Agendar Notificações por E-mail',

'LBL_EXPAND_CLOSE_MENU'=>'Expandir/Fechar Menu',

'LBL_CONFIGURATION'=>'Configuração',

'LBL_CONFIGURE_MAIL_SERVER'=>' - Configurar Servidor Envio de Mensagem',

'LBL_BACKUP_SERVER_CONFIGURATION'=>'Configuração Servidor de Backup',

'LBL_BACKUP_SERVER_INFO'=>'Informação Servidor de Backup',

'LBL_BACKUP_SERVER_SETTINGS'=>'Configuração Servidor de Backup',

'LBL_CONFIGURE_BACKUP_SERVER'=>' - Configurar Servidor de Backup',

'LBL_SYSTEM_CONFIGURATION'=>' - Configuração do Sistema',

'LBL_PROXY_SERVER_CONFIGURATION'=>'Configuração Servidor Proxy',

'LBL_PROXY_SERVER_INFO'=>'Informação Servidor Proxy',

'LBL_PROXY_SERVER_SETTINGS'=>'Servidor Proxy',

'LBL_CONFIGURE_PROXY_SERVER'=>' - Configurar Servidor Proxy',

'LBL_PROXY_PORT'=>'Número Porta',



//Field Types for custom fields

'LBL_URL'=>'URL',

'LBL_CHECK_BOX'=>'Checkbox',



//PickList Settings

'LBL_STANDARD_FIELDS'=>'Campos Padrões',

'LBL_LEAD_SOURCE'=>'Fonte Lead',

'LBL_SALUTATION'=>'Saudação',

'LBL_LEAD_STATUS'=>'Status Lead',

'LBL_INDUSTRY'=>'Atividade',

'LBL_RATING'=>'Avaliação',

'LBL_ACCOUNT_TYPE'=>'Tipo Organização',

'LBL_BUSINESS_TYPE'=>'Tipo Negócio',

'LBL_CURRENCY_TYPE'=>'Tipo Moeda',

'LBL_SALES_STAGE'=>'Estágio Vendas',

'LBL_PRIORITY'=>'Prioridade',

'LBL_STATUS'=>'Status',

'LBL_CATEGORY'=>'Categoria Ticket',

'LBL_MANUFACTURER'=>'Fabricante',

'LBL_PRODUCT_CATEGORY'=>'Categoria de Produto',

'LBL_RSS_CATEGORY'=>'Categoria de RSS',

//Added for Web based Email client integration (post 4.0.1 release)

'LBL_ADD_MAIL_ACCOUNT'=>'Adiciona Conta Correio',
'LBL_NEW_MAIL_ACCOUNT_TITLE'=>'Nova Conta Correio [Alt+M]',
'LBL_NEW_MAIL_ACCOUNT_KEY'=>'M',
'LBL_NEW_MAIL_ACCOUNT_LABEL'=>'Nova Conta Correio',
'LBL_GENERAL_INFO'=>'Informação Geral',
'LBL_DISPLAY_NAME'=>'Nome Exibição',
'LBL_MAIL_PROTOCOL'=>'Protocolo Correio',
'LBL_LIST_PASSWORD'=>'Senha',
'LBL_MAIL_SERVER_NAME'=>'Nome Servidor Correio ou IP',
'LBL_MAIL_SERVER_SETTINGS'=>'Servidor Envio Mensagem',
'LBL_INCOME_SERVER_SETTINGS'=>'Servidor Recebimento Mensagem',
'LBL_TEST_SETTINGS'=>'Testar Configuração da minha Conta imediatamente',
'LBL_TEST_BUTTON_TITLE'=>'Testar minha Conta agora! [Alt+T]',
'LBL_TEST_BUTTON_KEY'=>'T',
'LBL_TEST_BUTTON_LABEL'=>'Testar minha Conta agora!',
'LBL_DEFAULT'=>'Padrão',
'LBL_IMAP2'=>'IMAP2',
'LBL_IMAP4'=>'IMAP4',
'LBL_POP'=>'POP',
'LBL_IMAP'=>'IMAP',
'LBL_MAIL_DISCLAIM'=>'Itens marcados com <font color="red">*</font> são requerido<br>Itens marcados com <font color="red">**</font> não são totalmente suportados',
'LBL_SSL_OPTIONS'=>'Opções SSL',
'LBL_TLS'=>'TLS',
'LBL_NO_TLS'=>'Sem TLS',
'LBL_CERT_VAL'=>'Validações Certificado',
'LBL_INT_MAILER'=>'Usar Sistema envio E-mail Interno?',
'LBL_INT_MAILER_USE'=>'Sim',
'LBL_INT_MAILER_NOUSE'=>'não',
'LBL_VAL_SSL_CERT'=>'Validar SSL',
'LBL_DONOT_VAL_SSL_CERT'=>'não Validar SSL',
'LBL_WEB_MAIL_CONFIG'=>'Configuração Web Mail',
'LBL_CONFIGURE_WEB_MAIL'=>' - Configurar Web Mail',
'LBL_LIST_MAIL_ACCOUNT'=>'  Listar Contas Correio',
'LBL_USAGEUNIT'=>'Unidade Utilizada',
'LBL_GLACCT'=>'Conta Plano Contas',
'LBL_QUOTE_STAGE'=>'Estágio Cotação',
'LBL_CARRIER'=>'Transportador',
'LBL_TAXCLASS'=>'Categoria Imposto',
'LBL_MY_DETAILS'=>'Meus Detalhes',
'LBL_MY_MAIL_SERVER_DET'=>'Detalhes Meu Servidor Recebimento Mensagem',
'LBL_EMAIL_ID'=>'E-mail',
'LBL_NAME_EXAMPLE'=>'(exemplo : João da Silva)',
'LBL_EMAIL_EXAMPLE'=>'(exemplo : joaosilva@xyz.com.br)',
'LBL_REFRESH_TIMEOUT'=>'Atualizar Timeout',
'LBL_1_MIN'=>'1 minuto',
'LBL_2_MIN'=>'2 minutos',
'LBL_3_MIN'=>'3 minutos',
'LBL_4_MIN'=>'4 minutos',
'LBL_5_MIN'=>'5 minutos',
'LBL_EMAILS_PER_PAGE'=>'Emails por Página',

//Added for Organization Details (4.2 release)
'LBL_ORGANIZATION_NAME'=>'Nome Empresa',
'LBL_ORGANIZATION_ADDRESS'=>'Endereço',
'LBL_ORGANIZATION_CITY'=>'Cidade',
'LBL_ORGANIZATION_STATE'=>'Estado',
'LBL_ORGANIZATION_CODE'=>'CEP',
'LBL_ORGANIZATION_COUNTRY'=>'País',
'LBL_ORGANIZATION_PHONE'=>'Fone',
'LBL_ORGANIZATION_FAX'=>'Fax',
'LBL_ORGANIZATION_WEBSITE'=>'Website',
'LBL_ORGANIZATION_DETAILS'=>'Informação da Empresa',
'LBL_SPECIFY_COMPANY_DETAILS'=>' - Especificar Informação da Empresa',
'LBL_ORGANIZATION_LOGO'=>'Logo da Empresa',
'LBL_UPLOAD'=>'Upload',
'LBL_FILENAME'=>'Nome Arquivo',
'LBL_SETTINGS'=>'Configurações',
'LBL_COMPANY_DETAILS'=>'Detalhes da Empresa',

'LBL_SEVERITY'=>'Gravidade',
'LBL_FAQ_CATEGORY'=>'Categoria da FAQ',
'LBL_VENDOR_FIELD_ACCESS'=>'Acesso Campo Fornecedor',
'LBL_PB_FIELD_ACCESS'=>'Acesso Campo Lista Preço',
'LBL_QUOTE_FIELD_ACCESS'=>'Acesso Campo Cotação',
'LBL_PO_FIELD_ACCESS'=>'Acesso Campo Pedido Compra',
'LBL_SO_FIELD_ACCESS'=>'Acesso Campo Pedido Venda',
'LBL_INVOICE_FIELD_ACCESS'=>'Acesso Campo Fatura',
'INVENTORYNOTIFICATION'=>'Notificações Estoque',
'LBL_INVENTORY_NOTIFICATIONS'=>' - Edita Email Notificação Estoque',
'INVENTORYTERMSANDCONDITIONS'=>'Estoque: Prazos e Condições', //newly added for Inventory terms and conditions
'LBL_INVENTORY_TERMSANDCONDITIONS'=>' - Editar Prazos e Condições', //newly added
'LBL_TANDC_TEXT'=>'Texto Prazos & Condições',
'LBL_INVENTORY_TANDC'=>'Prazos & Condições',

'LBL_OTHER_SETTINGS'=>'Outras Configurações',
'LBL_SCROLL'=>'[Topo]',

'LBL_INV_NOT_DESC'=>'Esta é a Lista de Notificações enviadas para o Almoxarife lembrando-o sobre a procura e a quantidade atual durante a emissão de uma Cotação, Pedido de Venda e Fatura.',

'InvoiceNotification'=>'Notificação do Estoque de Produto durante Geração da Fatura',
'InvoiceNotificationDescription'=>'Quando o nível de estoque do produto ficar abaixo do nível de reposição, uma Notificação será enviada para o Almoxarife',
'Vendor'=>'Fornecedor',
'PriceBook'=>'Lista Preço',
'Quotes'=>'Cotação',
'PurchaseOrder'=>'Pedido Compra',
'SalesOrder'=>'Pedido Venda',
'Invoice'=>'Fatura',

//For Custom Fields
'LBL_LEAD_MAP_CUSTOM_FIELD'=>'Mapear Campos Customizado do Lead',
'leadCustomFieldDescription'=>'Mapear cada campo customizado do Lead para cada campo customizado de sua Organização
,Contato, ou Oportunidade. Este mapeamento será usado quando você converter Leads',
'LBL_MAPPING_INFO'=>'Informação Mapeamento',
'LBL_ACCOUNT_FIELD'=>'Customizar Campo Organização',
'LBL_CONTACT_FIELD'=>'Customizar Campo Contato',
'LBL_POTENTIAL_FIELD'=>'Customizar Campo Oportunidade',
'CUSTOMFIELDMAPPING'=>'Mapeando Customizar Campo',
'LBL_FIELD_MAPPING'=>'Mapeando Campo',
'LBL_LEAD_FIELD'=>'Customizar Campo Lead',
//After 4.2 GA
'LBL_TEXT_AREA'=>'Área de Texto',
//for Edit ordering the blocks
'NOTESCUSTOMFIELDS'=>'Campos Customizados de Documentos',

//Added fields after 4.2 ptach 2
'LBL_ASSIGN_MODULE_OWNERS'=>'Definir Proprietário do Módulo',
'LBL_MODULE_OWNERS'=>'Proprietário Módulo',
'LBL_ASSIGN_MODULE_OWNERS_INFO'=>' - Definir Proprietários para cada Módulo',
'LBL_MODULE'=>'Módulo CRM',
'LBL_OWNER'=>'Proprietário Responsável',
'LBL_MIGRATION'=>'Migração Orientada',
'LBL_MIGRATION_INFO'=>'Migrar dados da Versão anterior do vtiger CRM',

//Added for 5 GA - Description of Settings UI

'LBL_USER_DESCRIPTION'=>'Administrar Usuários que podem acessar o vtiger CRM',
'LBL_ROLE_DESCRIPTION'=>'Definir hierarquia das Funções e Atribuições para Usuários',
'LBL_PROFILE_DESCRIPTION'=>'Administrar acesso de Usuários a Módulos específicos para diferentes Funções',
'LBL_GROUP_DESCRIPTION'=>'Administrar tipos diferentes de Equipes baseados em Funções, Usuários, Perfis etc',
'LBL_SHARING_ACCESS_DESCRIPTION'=>'Administrar Módulo de Compartilhamento para Funções Padrões & Funções Customizadas',
'LBL_SHARING_FIELDS_DESCRIPTION'=>'Definir nível de acesso global em cada campo do Módulo',
'LBL_MODULE_OWNERS_DESCRIPTION'=>'Definir responsáveis pelo Suporte ao Cliente nos Módulos do CRM',
'LBL_ANNOUNCEMENT_DESCRIPTION'=>'Administrar Anúncios da Empresa',
'LBL_CUSTOM_FIELDS_DESCRIPTION'=>'Administrar tipos diferentes de campos definidos pelo Usuário',
'LBL_PICKLIST_DESCRIPTION'=>'Customizar Lista de Opções em cada Módulo',
'LBL_EMAIL_TEMPLATE_DESCRIPTION'=>'Administrar modelos para Módulo de E-Mail',
'LBL_MAIL_MERGE_DESCRIPTION'=>'Administrar modelos de Correspondências',
'LBL_NOTIF_SCHED_DESCRIPTION'=>'Administrar Notificações que serão disparadas em caso de ações importante',
'LBL_INV_NOTIF_DESCRIPTION'=>'Mudar Configurações das Notificações relacionadas ao Estoque',
'LBL_INV_TANDC_DESCRIPTION'=>'Especificar Prazos e Condições para Cotações, Pedidos e Faturas',
'LBL_COMPANY_DESCRIPTION'=>'Especificar Endereço comercial da Empresa',
'LBL_MAIL_SERVER_DESCRIPTION'=>'Configurar detalhes do Servidor de Envio Mensagem',
'LBL_BACKUP_SERVER_DESCRIPTION'=>'Especificar detalhes do Servidor de Backup',
'LBL_CURRENCY_DESCRIPTION'=>'Administrar Moedas Internacionais e Taxas de Câmbio',
'LBL_TAX_DESCRIPTION'=>'Administrar Impostos e respectivas alíquotas',
'LBL_SYSTEM_DESCRIPTION'=>'Visualizar detalhes do Servidor vtiger CRM',
'LBL_PROXY_DESCRIPTION'=>'Configurar proxies para acesso a alimentadores RSS através da Internet',
'LBL_AUDIT_DESCRIPTION'=>'Exibir as operações executadas por Usuários',
'LBL_TAX_DESC'=>'Administrar diferentes tipos de alíquotas de impostos: IPI, ICMS etc.',
'LBL_COMPANY_DESC'=>'Especificar Endereço comercial de sua Empresa',
'LBL_SELECT_LOGO'=>'Selecionar nova logo :',
'LBL_INVEN_TANDC_DESC'=>'Especificar o texto para Prazo & Condições nos Módulos Estoque, Pedidos de Compras, Vendas e Faturas.',
'LBL_MAIL_SERVER_DESC'=>'Configurar detalhes de seu Servidor de Envio de Mensagens',
'LBL_BACKUP_SERVER_DESC'=>'Administrar seu Servidor de Backup',
'LBL_MODULES_AND_OWNERS'=>'Proprietários & Módulos',
'LBL_GROUP_DESC'=>'Administrar diferentes tipos de Grupos de Usuários na Organização',
'LBL_MAIL_MERGE_DESC'=>'Administrar modelos de Correspondências utilizadas nos Módulos do CRM',


//Added fields after 5.0 Alpha
'LBL_REQUIRE_SMTP_AUTHENTICATION'=>'Requer Autenticação SMTP?', //Contribuição de Jader Marasca - 25/09/2010
'LBL_ANNOUNCEMENT'=>'Anúncios',
'LBL_SETTING_ANNOUNCEMENT'=>'Anúncio',
'LBL_ANNOUNCE_TEXT'=>'Texto do Anúncio',
'LBL_UPDATE_BUTTON'=>'Atualizar',
'LBL_ANNOUNCEMENT_INFO'=>'Digite abaixo o texto da apresentação, e clique no botão Salvar.',
'LBL_ANNOUNCEMENT_DESC'=>'Mudar o texto que aparece no Anúncio no topo de cada Página',
'LBL_EMAIL_CONTENTS'=>'Conteúdo do E-mail',
'LBL_SUBJECT'=>'Assunto',
'LBL_MESSAGE'=>'Mensagem',
'LBL_PICKLIST_EDITOR'=>'Editor Lista Opções',
'LBL_PICKLIST_AVAIL'=>'Lista Opções disponível em',
'LBL_PICKLIST_AVAILINFO1'=>'As Listas de Opções Disponíveis em',
'LBL_PICKLIST_AVAILINFO2'=>'são apresentadas abaixo. Clique Editar para modificar o Conteúdo da Lista.',
'LBL_EDIT_PICKLIST'=>'Editar Lista de Opções',
'LBL_PICKLIST_SAVEINFO'=>'Digite as entradas abaixo - uma por uma e clique no botão Salvar para salvar a Lista.',
'LBL_SELECT_CRM_MODULE'=>'Selecionar Módulo CRM',
'LBL_TAX_SETTINGS'=>'Cálculo Imposto',
'LBL_INVENTORY_TAX_CONFIG'=>'Configuração Imposto Estoque',
'LBL_CUSTOM_MAPP_INFO'=>'Somente o Módulo Leads suporta mapeamento de campos com outros Módulos.',
'LBL_MAPPING_OTHER_MODULES'=>'Mapeamento com outros Módulos',
'LBL_CUSTOM_FILED_IN'=>'Customizar Campos em ',
'LBL_ROLE_HIERARCHY_TREE'=>'Árvore de Funções & Hierarquia',
'LBL_EDIT_FIELD_MAPPING'=>'Editando Mapeamento de Campo',
'LBL_LOGIN_HISTORY_DETAILS'=>'Histórico Login Usuário',
'LBL_LOGIN_HISTORY_DESCRIPTION'=>'apresentação Histórico login Usuários',
'LBL_NON_EDITABLE_PICKLIST_ENTRIES'=>'Entradas não Editáveis da Lista de Opções',

//Added for Tax settings
'LBL_PRODUCT_TAX_SETTINGS'=>'Impostos Produto & Serviços',
'LBL_SHIPPING_HANDLING_TAX_SETTINGS'=>'Impostos s/ Fretes',
'LBL_PROXY_SERVER_DESC'=>'Configurar proxies para acesso aos Alimentadores RSS através da Internet',

'LBL_NEW_CURRENCTY'=>'Nova Moeda',
'LBL_BASE_CURRENCY'=>'Moeda Base - ',
'LBL_DELETE_CURRENCY'=>'Apagar Moeda',

//Added for singlepane view in modules

'LBL_DEFAULT_DETAIL_VIEW'=>'Padrão Detalhes Visualização',
'LBL_DEFAULT_MODULE_VIEW'=>'Padrão Visualização Módulo',
'LBL_DEFAULT_MODULE_VIEW_DESC'=>'Configurar Padrão Visualização',
'LBL_ENABLE_SINGLEPANE_VIEW'=>'Habilitar Visualização Monolí­tica',

'LBL_CLEAR_DATA'=>'Limpar Dados',
'LBL_ENABLE'=>'Habilitado',
'LBL_FAQ_FIELD_ACCESS'=>'Acesso Campo FAQ',
'LBL_ADD_TAX_BUTTON'=>'Adicionar Imposto',
'LBL_NO_TAXES_AVAILABLE'=>'Nenhum Imposto',
'LBL_PLEASE'=>'Por favor',
//Added while moving role file from User to Setting Module
'LBL_ROLES'=>'Funções',
'LBL_CREATE_NEW_ROLE'=>'Criar Nova Função',
'LBL_PROPERTIES'=>'Propriedade da',
'LBL_NEW_ROLE'=>'Nova Função',
'LBL_ROLE_NAME'=>'Nome Função',
'LBL_REPORTS_TO'=>'Reporta-se à:',
'LBL_PROFILE_M'=>'Perfil',
'LBL_PROFILES_AVLBL'=>'Perfis Disponíveis',
'LBL_ASSIGN_PROFILES'=>'Perfis Atribuídos',
'LBL_MEMBER'=>'Membros',
'LBL_DELETE_ROLE'=>'Apagar Função',
'LBL_ROLE_TO_BE_DELETED'=>'Função a ser Apagada',
'LBL_TRANSFER_USER_ROLE'=>'Transferir Usuários para Função',
'LBL_ASSOCIATED_PROFILES'=>'Perfis Associados :',
'LBL_ASSOCIATED_USERS'=>'Usuários Associados :',
//Added while moving email templates from Users to Settings
'LBL_EMAIL_TEMPLATES'=>'Modelos E-mail',
'LBL_EMAIL_TEMPLATE_DESC'=>'Administrar modelos de email usados para Campanhas e Mala Direta',
'LBL_LIST_SELECT'=>'Selecionar',
'LBL_EMAIL_TEMPLATE'=>'Modelo E-mail',
'LBL_TEMPLATE_TOOLS'=>'Ferramentas',
'LBL_NEW_TEMPLATE' =>'Novo Modelo',
'LBL_FOLDER'=>'Folder',
'LBL_NAME'=>'Nome',
'LBL_PERSONAL'=>'Pessoal',
'LBL_PUBLIC'=>'Público',
'LBL_ACCOUNT_FIELDS'=>'Campos Organização',
'LBL_CONTACT_FIELDS'=>'Campos Contato',
'LBL_LEAD_FIELDS'=>'Campos Lead',
'LBL_USER_FIELDS'=>'Campos do Usuário',
'LNK_SAMPLE_EMAIL'=>'Visualizar Exemplo Email',
//Added while moving Mail Merge templates from Users to Settings
'LBL_TEMPLATE_FILE'=>'Arquivo do Modelo',
'LBL_MODULENAMES'=>'Módulo',
'LBL_DOWNLOAD'=>'Download',
'LBL_ADD_TEMPLATE'=>'Adicionar Modelo',
'LBL_WORD_TEMPLATES'=>'Modelo de Correspondência',
//Added while moving Notification Schedulers from Users to Settings
'LBL_TASK_NOTIFICATION'=>'Notificação Tarefas Atrasadas',
'LBL_BIG_DEAL'=>'Notificação Grande Negócio',
'LBL_PENDING_TICKETS'=>'Notificação Tickets Pendentes',
'LBL_MANY_TICKETS'=>'Notificação Tickets em demasia',
'LBL_START_NOTIFICATION'=>'Notificação Início do Suporte',
'LBL_ACTIVITY_NOTIFICATION'=>'Notificação Lembrete Evento',

'LBL_TASK_NOTIFICATION_DESCRITPION'=>'Notificação quando uma Tarefa está atrasada a mais de 24 h',
'LBL_BIG_DEAL_DESCRIPTION'=>'Notificação quando existe um grande Negócio',
'LBL_TICKETS_DESCRIPTION'=>'Notificação para verificar Tickets pendentes',
'LBL_MANY_TICKETS_DESCRIPTION'=>'Notificação quando um Usuário recebe muitos Tickets, podendo afetar o desempenho do nível de Serviço',
'LBL_START_DESCRIPTION'=>'Notificação sobre a situação do Início do Suporte/Serviço',
'LBL_ACTIVITY_REMINDER_DESCRIPTION'=>'Notificação antes de um evento ocorrer baseado no Lembrete',
//Added while moving Inventory Notifications from Users to Settings
'QuoteNotificationDescription'=>'Durante a Geração da Cotação, se o estoque do produto na Loja for menor que a quantidade mencionada na Cotação esta Notificação será enviada para o Almoxarife',
'SalesOrderNotificationDescription'=>'Durante Geração do Pedido de Venda, se o estoque do produto na Loja for menor que a quantidade mencionada no Pedido de Venda esta Notificação será enviada para o Almoxarife',
'Tools'=>'Ferramentas',
'QuoteNotification'=>'Notificação de Estoque de Produto durante Geração de Cotação',
'SalesOrderNotification'=>'Notificação de Estoque de Produto durante Geração do Pedido de Venda',
'LBL_NOTE_DO_NOT_REMOVE_INFO'=>'Nota: não remova ou altere o valores dentro {  }',

//Added while moving Profile file from User to Setting Module
'LBL_TOTAL'=>'Total :',
'LBL_NEW_PROFILE'=>'Novo Perfil',
'LBL_LIST_NO'=>'#',
'LBL_NEW_PROFILE_NAME'=>'Nome Perfil',
'LBL_LIST_TOOLS'=>'Ferramentas',
'LBL_PROFILE_MESG'=>'Visualizar privilégios de acesso para',
'LBL_PROFILE_PRIVILEGES'=>'Privilégios Perfil',
'LBL_DEFINE_PRIV_FOR'=>' Definir Privilégios para',
'LBL_USE_OPTION_TO_SET_PRIV'=>'Usar as Opções abaixo para definir privilégios',
'LBL_SUPER_USER_PRIV'=>'Privilégios Global',
'LBL_SET_PRIV_FOR_EACH_MODULE'=>'Configurar Privilégios para cada Módulo',
'LBL_FIELDS_AND_TOOLS_SETTINGS'=>'Configurações Campos & Ferramentas',
'LBL_VIEW_ALL'=>'Visualizar todos',
'LBL_EDIT_ALL'=>'Editar todos',
'LBL_ALLOW'=>'Permitidos',
'LBL_MESG_VIEW'=>'para visualizar todas as informações / Módulos do vtiger CRM',
'LBL_MESG_EDIT'=>'para editar todas as informações / Módulos do vtiger CRM',
'LBL_TAB_MESG_OPTION'=>'Módulos para serem apresentados',
'LBL_CREATE_EDIT'=>'Criar/Editar',
'LBL_VIEW'=>'Visualizar',
'LBL_MANDATORY_MSG'=>'Campos Obrigatórios',
'LBL_DISABLE_FIELD_MSG'=>'Campos das Configurações Gerais de Acesso Desabilitados',
'LBL_DELETE'=>'Apagar',

'LBL_STEP_2_2'=>'Passo 2 de 2',
'LBL_FINISH_BUTTON'=>'Final',

//Added while moving Groups file from User to Setting Module
'LBL_NEW_GROUP'=>'Novo Grupo',
'LBL_GROUPS'=>'Grupos',
'LBL_GROUP_NAME'=>'Nome Grupo',
'LBL_ROLES_SUBORDINATES'=>'Subordinados e Funções',
'LBL_MEMBER_AVLBL'=>'Membros & Entidades Disponíveis',
'LBL_MEMBER_SELECTED'=>'Membros Selecionados',
'LBL_ENTITY'=>'Entidade',
'LBL_OF'=>'de',
'LBL_CREATE_NEW_GROUP'=>'Criar Novo Grupo',
'LBL_ADD_GROUP_BUTTON'=>'Adicionar Grupo',
'LBL_GROUP_MESG1'=>'A criação de Grupos é uma forma flexivel para conceder privilégios quando direitos de acesso mais complexos forem exigidos. você pode combinar múltiplas entidades tais como Funções, Usuários, Perfis etc. em um simples Grupo.',
'LBL_GROUP_MESG2'=>'Para adicionar, selecione os membros da Entidade da esquerda e clique no botão ">>".',
'LBL_GROUP_MESG3'=>'Para remover, selecione os membros do Grupo da direita e clique no botão "<<".',

//Sharing Privileges
'LBL_GLOBAL_ACCESS_PRIVILEGES'=>'Privilégio Acesso Global',
'LBL_RECALCULATE_BUTTON'=>'Recalcular',
'LBL_CHANGE'=>'Mudar',
'LBL_PRIVILEGES'=>'Privilégios',
'LBL_CUSTOM_ACCESS_PRIVILEGES'=>'Privilégio Acesso Customizado',
'LBL_ADD_PRIVILEGES_BUTTON'=>'Adicionar Privilégio',
'LBL_RULE_NO'=>'No. Função',
'LBL_CAN_BE_ACCESSED'=>'pode ser acessado por',
'LBL_CUSTOM_ACCESS_MESG'=>'Funções para Acesso Customizado não definidas .',
'LNK_CLICK_HERE'=>'Clique aqui',
'LBL_CREATE_RULE_MESG'=>'para criar uma nova Função',
'LBL_RECALC_MSG'=>'Tem certeza que deseja recalcular o Acesso Compartilhado?',
'LBL_YES'=>'Sim',
'LBL_NO'=>'não',
'LBL_IN_PERMISSION'=>'na permissão',
'LBL_RELATED_MODULE_RIGHTS'=>'Direitos Módulo Relacionado',
'LBL_USR_CAN_ACCESS'=>'Usuário pode ',
'LBL_USR_OTHERS'=>' outro Usuário ',
'LBL_USR_CANNOT_ACCESS'=>'Usuários não podem acessar outros Usuários ',

'LBL_ORG_SHARING_PRIVILEGES'=>'Privilégios Compartilhados na Organização',
'LBL_EDIT_PERMISSIONS'=>'Editar permissão',
'LBL_SAVE_PERMISSIONS'=>'Salvar permissão',
'LBL_READ_ONLY'=>'Publico: Só Leitura',
'LBL_EDIT_CREATE_ONLY'=>'Público: Ler, Criar/Editar',
'LBL_READ_CREATE_EDIT_DEL'=>'Público: Ler, Criar/Editar, Del',
'LBL_PRIVATE'=>'Particular',

'Public: Read Only'=>'Público: Só Leitura',

'Public: Read, Create/Edit'=>'Público: Ler, Criar/Editar',

'Public: Read, Create/Edit, Delete'=>'Público: Ler, Criar/Editar, Del',

'Private'=>'Particular',
'Hide Details'=>'Omitir Detalhes',
'Hide Details and Add Events'=>'Omitir Detalhes e Adicionar Eventos',
'Show Details'=>'Mostrar Detalhes',
'Show Details and Add Events'=>'Mostrar Detalhes e Adicionar Eventos',

//Added for User Login History While moving from User to Settings
'LBL_LOGIN_HISTORY'=>'Histórico Login',
//Sharing Access module moved to Setting
'Read/Write'=>'Leitura/Escrita',
'Read Only '=>'Só Leitura ',
'LBL_GROUP'=>'Grupo',
'LBL_ACCESS_RIGHTS_FOR_MODULES'=>'Direitos de acesso para Módulos relacionados',
'LBL_ADD_RULE'=>'Adicionar Função',
'LBL_ADD_CUSTOM_RULE'=>'Adicionar Privilégio para Função Customizada',
'LBL_RULE_CONSTRUCTION'=>'Tela Construção de Função',
'LBL_STEP'=>'Passo',
'LBL_SELECT_ENTITY'=>'Selecionar uma entidade abaixo',
'LBL_CAN_BE_ACCESSED_BY'=>'Pode ser acessado por',
'LBL_PERMISSIONS'=>'Permissões',
'LBL_DOC_MSWORD'=>'O arquivo deverá ser um Documento do tipo doc/msword',
'LBL_NODOC'=>'Nenhum arquivo <b>doc</b> neste diretório. Por favor, tente novamente!',

//Added for error messages on Company Info.
'LOGO_ERROR'=>'A logo deve ser uma imagem do tipo jpeg/png',
'Error_Message'=>'Mensagem de erro',
'Invalid_file'=>'Arquivo inválido OU',
'File_has_no_data'=>'O arquivo não contém dados',
'Sorry'=>'Desculpe',
'uploaded_file_exceeds_maximum_limit'=>'o arquivo transferido excedeu o limite máximo vtiger_filesize',
'try_file_smaller'=>'Por favor tente um arquivo menor que 800000 bytes',
'Problems_in_upload'=>'Problemas na transferência do arquivo',
'Please_try_again'=>'Por favor tente novamente!',
//5.0.3 fixes
'LBL_TESTMAILSTATUS'=>'Status Teste Mensagem:',
'LBL_CHECK_ASSIGNEDTO_MAILID'=>'Por favor, verifique o Endereço de e-mail determinado',
'LBL_MAILSENDERROR'=>'A mensagem não pode ser enviada para o Usuário admin. Por favor verifique o Endereço de e-mail do admin',
'LBL_RECORD_NOEXIST'=>'Registro não disponível',
'LBL_ENTER_PROFILE'=>'Digite o Nome do Perfil',
'LBL_ENABLE'=>'Habilitado',
'LBL_DISABLE'=>'Desabilitado',
'LBL_PROXY'=>'proxy',
'LBL_FIELDS_TO_BE_SHOWN'=>'Campos a serem apresentados',
//Added for alerts
'SPECIFY_FILE_TO_MERGE' => 'Por favor, especifique uma Arquivo para Mesclar',
'FILESIZE_EXCEEDS_INFO_CONFIG_INC' => 'Desculpe, o arquivo transferido excedeu o tamanho máximo definido no arquivo config.inc.php. Tente arquivo menor. ',
'FILESIZE_EXCEEDS_INFO_PHP_INI' => 'Desculpe, o arquivo transferido excedeu o tamanho máximo definido no arquivo php.ini. Tente arquivo menor. ',
'PROBLEMS_IN_FILEUPLOAD' => 'Problemas na transferência do arquivo. Por favor tente novamente!',

//Added fields for Invoice Number labels
'LBL_CUSTOMIZE_INVOICE_NUMBER'=>'Customizar Número Fatura',
'LBL_CUSTOMIZE_INVOICE_NUMBER_DESCRIPTION'=>'Customização Número Fatura',
'LBL_CUSTOM_INVOICE_NUMBER_VIEW'=>'Customização Número Fatura',
'LBL_CUSTOMINVOICE_STRING'=>'Customizar String da Fatura',
'LBL_CUSTOMINVOICE_NUMBER'=>'Customizar Número Fatura',
'LBL_INVOICE_NUMBER_PREVIEW'=>'Visualização',
'LBL_INVOICE_NUMBER_BUTTON'=>'Atualizar Número Fatura',
'LBL_PROXY_AUTHENTICATION_REQUIRED'=>'Requerido Administração Proxy',
'LBL_ENABLE_FTP' => 'você precisa ter suporte à FTP habilitado em php',

//Added for Role Labels
'LBL_ADD_ROLE'=>'Adicionar Função',
'LBL_EDIT_ROLE'=>'Editar Função',
'LBL_MOVE_ROLE'=>'Mover Função',
'LBL_BACKUP_DESC'=>' O Sistema de CRM permite-lhe fazer backup do Banco de Dados salvando-o em seu Servidor FTP. O CRM fará backup de todos os dados toda vez que o Administrador sair do Sistema. Verifique se existe espaço suficiente no seu Servido FTP. O arquivo backup criado terá o seguinte formato: "backup_date_time.sql".',

// Added/Updated for vtiger CRM 5.0.4
'LBL_SUPPORT_NOTICIATION'=>'Notificação Fim do Suporte',
'LBL_SUPPORT_NOTICIATION_MONTH'=>'Notificação de Final de Suporte antecedência mensal' ,
'LBL_SUPPORT_DESCRIPTION'=>'Notificar quando o suporte estiver quase no fim',
'LBL_SUPPORT_DESCRIPTION_MONTH'=>'Notificar com antecedência de um mês quando o suporte estiver prestes a terminar',
'LBL_SELECT_ROLE'=>'Selecionar Função',
'LBL_TEMPLATE'=>'Modelo',
'LBL_SELECT_EMAIL_TEMPLATE_FOR'=>'Selecione o Modelo de E-mail para',

'ERR_CUSTOM_FIELD_WITH_NAME'=>'Customzar Campo com o Nome ',
'ERR_ALREADY_EXISTS'=>' já existe.',
'ERR_SPECIFY_DIFFERENT_LABEL'=>'Por gentileza, especifique um Rótulo diferente',
'LBL_TOOLS_TO_BE_SHOWN'=>'Ferramentas a serem exibidas',
'LBL_PICKLIST_GLOBAL_CHANGE'=>'Mudar Global',
'LBL_PICKLIST_TRANSFER'=>'Transferindo os valores de ',
'LBL_REPLACE_VALUE_WITH'=>'Substituir valor com ',
'LBL_EDIT_CUSTOM_RULE'=>'Editar Customizar Regras Privilégio',

/*for global add/delete in picklist*/
'DELETE_PICKLIST_VALUES'=>'Apagar valores Lista Opções',
'EDIT_PICKLIST_VALUE'=>'Editar Valores Lista Opções',
'ADD_PICKLIST_VALUES'=>'Adicionar Valores Lista Opções',
'LBL_PICKLIST_ADDINFO'=>'Digite abaixo nova entrada uma por uma',
'LBL_SELECT_ROLES'=> 'Selecionar a Função para a qual as entradas serão adicionadas',
'LBL_EXISTING_PICKLIST_VALUES'=>'Valores Lista Opções Existente',
'LBL_SELECT_PICKLIST'=>'Selecionar Lista Opções',

// Added after 5.0.4 GA

'LBL_GENERAL_FIELDS'=>'Campos Gerais',

'LBL_CANCEL_BUTTON'=>'Cancelar',

//Added fields for Inventory Number labels
'LBL_CUSTOMIZE_INVENTORY_NUMBER'=>'Customizar Numeração',
'LBL_CUSTOMIZE_INVENTORY_NUMBER_DESCRIPTION'=>'Customizar Numeração da Cotação, Pedidos e Fatura',
'LBL_CUSTOM_QUOTE_NUMBER_VIEW'=>'Customização Número Cotação',
'LBL_CUSTOMQUOTE_STRING'=>'Customizar String Cotação',
'LBL_CUSTOMQUOTE_NUMBER'=>'Customizar Número Cotação',
'LBL_QUOTE_NUMBER_PREVIEW'=>'Visualização',
'LBL_QUOTE_NUMBER_BUTTON'=>'Atualizar Número Cotação',
'LBL_CUSTOM_SO_NUMBER_VIEW'=>'Customização Número Pedido Venda',
'LBL_CUSTOMSO_STRING'=>'Customizar String Pedido Venda',
'LBL_CUSTOMSO_NUMBER'=>'Customizar Número Pedido Venda',
'LBL_SO_NUMBER_PREVIEW'=>'Visualização',
'LBL_SO_NUMBER_BUTTON'=>'Atualizar Número Pedido Venda',
'LBL_CUSTOM_PO_NUMBER_VIEW'=>'Customização Número Pedido Compra',
'LBL_CUSTOMPO_STRING'=>'Customizar String Pedido Compra',
'LBL_CUSTOMPO_NUMBER'=>'Customizar Número Pedido Compra',
'LBL_PO_NUMBER_PREVIEW'=>'Visualização',
'LBL_PO_NUMBER_BUTTON'=>'Atualizar Número Pedido Compra',

// Added after 5.0.4 GA

// Added for Multi-Currency Support
'LBL_TRANSFER_CURRENCY'=>'Transferir Moeda',
'LBL_CURRENT_CURRENCY'=>'Moeda Atual',

//Added for new backup labels
'LBL_LOCAL'=>'Local',
'LBL_BACKUP'=>'Backup',
'LBL_BACKUP_LOCATION'=>'Local do Backup',

'LBL_LAYOUT_EDITOR'=>'Editor de Layout',
'LBL_LAYOUT_EDITOR_DESCRIPTION'=>'Desenhar e Modificar o layout em cada um dos Módulos',
'LBL_Show'=>'Mostrar',
'LBL_Hide'=>'Ocultar',

// vtlib customization: Language Stings
'VTLIB_LBL_MODULE_MANAGER'=>'Gerenciador Módulos',
'VTLIB_LBL_MODULE_MANAGER_DESCRIPTION'=>'Gerenciar Comportamento Módulos no vtiger CRM',
'VTLIB_LBL_MODULE_MANAGER_CUSTOMMOD'=>'Módulos Customizados',
'VTLIB_LBL_MODULE_MANAGER_STANDARDMOD'=>'Módulos Padrões',
'VTLIB_LBL_MODULE_MANAGER_NOMODULES'=>'Nenhum Módulo customizado foi encontrado! Criar ou Importar Novo...',

// vtmailscanner START
'LBL_MAIL_SCANNER'=>'Scanner de Mensagem',
'LBL_MAIL_SCANNER_DESCRIPTION'=>'Configure Caixa Correio para Scanear',
'LBL_SCAN_NOW'=>'Escanear Agora',
'LBL_RULE'=>'Regra',
'LBL_SETUP'=>'Configuração',
'LBL_CONFIGURE'=>'Configurar',
'LBL_MAILBOX' => 'Caixa Correio',
'LBL_INFORMATION' => 'Informação',
'LBL_SCANNER' => 'Scanner',
'LBL_SERVER'  => 'Servidor',
'LBL_PROTOCOL'=> 'Protocolo',
'LBL_PASSWORD'=> 'Senha',
'LBL_TYPE' => 'Tipo',
'LBL_SSL' => 'SSL',
'LBL_METHOD'=> 'Método',
'LBL_VAL_SSL_CERT'=>'Validar Certificado SSL',
'LBL_DONOT_VAL_SSL_CERT'=>'não Validar Certificado SSL',
'LBL_STATUS'=>'Status',
'LBL_ENABLE'=>'Habilitar',
'LBL_DISABLE'=>'Desabilitar',
'LBL_CONNECT'=>'Conectar',
'LBL_URL_CAPS'=>'URL',
'LBL_ENABLED'=>'Habilitado',
'LBL_DISABLED'=>'Desabilitado',
'LBL_RULES'=>'Regras',
'LBL_FOR'=>'Para',

'LBL_FROM'=>'De',
'LBL_TO'=>'Para',

'LBL_ACTION'=>'Ação',
'LBL_CREATE'=>'Criar',
'LBL_TICKET'=>'Ticket',
'LBL_ADD'=>'Adicionar',

'LBL_CONTACT'=>'Contato',
'LBL_ACCOUNT'=>'Organização',

'LBL_FROM_CAPS'=>'DE',
'LBL_TO_CAPS'=>'PARA',
'LBL_TO_SMALL'=>'para',

'LBL_CONTAINS'=>'Contém',
'LBL_EQUALS'=>'Igual',

'LBL_BEGINS'=>'Inicia',

'LBL_REGEX'=>'Regex',
'LBL_ENDS'=>'Final',
'LBL_BODY'=>'Corpo',

'LBL_NOT'=>'não',

'LBL_ALL' => 'Todas',
'LBL_ANY'=>'Qualquer uma das',
'LBL_CONDITION'=>'Condições',
'LBL_ACTION'=>'Ação',
'LBL_MOVE'=>'Mover',
'LBL_UP'=>'Acima',
'LBL_DOWN'=>'Abaixo',
'LBL_PRIORITY'=>'Prioridade',
'LBL_UPDATE'=>'Atualizar',
'LBL_SELECT'=>'Selecionar',
'LBL_FOLDERS'=>'Pastas',
'LBL_UNSELECT'=>'Remover',
'LBL_MATCH'=>'Combinar',
'LBL_SCANNING'=>'Rastreando',
'LBL_LOOKFOR'=>'Procurar por',
'LBL_UNREAD'=>'não lida',
'LBL_READ'=>'Lida',
'LBL_AFTER_SCAN'=>'Rastrear depois',
'LBL_MESSAGES_FROM_LASTSCAN'=>'Mensagens do último rastreamento',
'LBL_MARK_MESSAGE_AS'=>'Marcar mensagem como',

//Added for the workflow module
'LBL_LIST_WORKFLOWS'=>'Workflows',
'LBL_LIST_WORKFLOWS_DESCRIPTION' => 'Criar e Editar Workflows para o vtiger',
'LBL_TASK_TITLE'=>'Título Tarefa',
'LBL_PARENT_WORKFLOW'=>'Workflow Pai',
'MSG_EXECUTE_TASK_DELAY'=>'Executar a Tarefa após certo tempo de atraso',
'LBL_AFTER'=>'Depois',
'LBL_BEFORE'=>'Antes',
'LBL_TASK_OPERATIONS'=>'Operações Tarefa',
'LBL_CREATE_TASK'=>'Criar Tarefa',
'LBL_CREATE_TASK_OF_TYPE'=>'Criar uma Tarefa nova do tipo',
'LBL_SUMMARY'=>'Sumário',
'LBL_WHEN_TO_RUN_WORKFLOW'=>'Quando executar o Workflow',
'LBL_ONLY_ON_FIRST_SAVE'=>'Somente na primeira vez em que for salvo',
'LBL_UNTIL_FIRST_TIME_CONDITION_TRUE'=>'Até a primeira vez em que a Condição for verdadeira',
'LBL_EVERYTIME_RECORD_SAVED'=>'Todas as vezes em que o registro for salvo',
'LBL_ON_MODIFY' => 'Todas as vezes que registro for modificado',
'LBL_CONDITIONS'=>'Condições',
'LBL_NEW_CONDITION_BUTTON_LABEL'=>'Nova Condição',
'LBL_TASKS'=>'Tarefas',
'LBL_NEW_TASK_BUTTON_LABEL'=>'Nova Tarefa',
'LBL_TASK'=>'Tarefa',
// END
//Added for vantage customization (Mandatory fields) -- Pavani
'LBL_MANDATORY_FIELDS'=>'Campos Obrigatórios',
'LBL_MANDATORY_FIELDS_DESCRIPTION'=>'Administrar campos Obrigatórios de todos os Módulos',
// Module Sequence Numbering
'LBL_CUSTOMIZE_MODENT_NUMBER'=>'Customizar Numeração Registros',
'LBL_CUSTOMIZE_MODENT_NUMBER_DESCRIPTION'=>'Customizar Número Entidade do Módulo',
// END

//added for softphone integration
'LBL_SOFTPHONE_SERVER_SETTINGS'=>'Configurações Servidor SoftPhone',
'LBL_SOFTPHONE_SERVER_SETTINGS_DESCRIPTION'=>'Configure aqui seu Softphone',
'ASTERISK_SERVER_IP'=>'IP Servidor Asterisk ',
'ASTERISK_PORT'=>'Porta Servidor Asterisk',
'ASTERISK_USERNAME'=>'Usuário Asterisk',
'ASTERISK_PASSWORD'=>'Senha Asterisk',
'ASTERISK_SERVER_IP_TITLE'=>'URL do Servidor Asterisk',
'ASTERISK_PORT_TITLE'=>'Porta em que a API do administrador de chamadas pode se conectar ao Asterisk (Porta Padrão: 5038)',
'ASTERISK_USERNAME_TITLE'=>'O Usuário Asterisk (geralmente o nome de Usuário admin)',
'ASTERISK_PASSWORD_TITLE'=>'Senha para o Usuário Asterisk',
'LBL_CANCEL_BUTTON'=>'Cancelar',
'ASTERISK_VERSION' => 'Versão Asterisk',
'ASTERISK_VERSION_TITLE'=>'Selecione, aqui, sua Versão do Asterisk; deixe-a como 1.4 se não tiver certeza',
'ASTERISK_CONFIGURATION'=>'Configuração Asterisk',
//softphone integration ends
'LBL_SELECT_FIELD_TO_MOVE' => 'Selecionar Campos para mover',
'VTLIB_LBL_SELECT_PACKAGE_FILE'=>'Selecionar Arquivo Pacote',
'VTLIB_LBL_FILE_LOCATION'=>'Localização Arquivo:',
'VTLIB_LBL_PACKAGE_FILE_HELP'=>'Módulos do vtiger são empacotados como arquivos zip.',
'VTLIB_LBL_IMPORT_FAILURE'=>'Falha Importante',
'VTLIB_LBL_INVALID_FILE'=>'Arquivo inválido',
'VTLIB_LBL_INVALID_IMPORT_TRY_AGAIN'=>'fornecido para importar Módulo! Tente novamente.',
'VTLIB_LBL_UNABLE_TO_UPLOAD'=>'Não é possível transferir',
'VTLIB_LBL_UNABLE_TO_UPLOAD2'=>'o pacote no Servidor! Tente novamente.',
'VTLIB_LBL_VERIFY_IMPORT_DETAILS'=>'Verifique Detalhes importação',
'VTLIB_LBL_MODULE_NAME'=>'Nome Módulo',
'VTLIB_LBL_MODULE_DIR'=>'Diretório Módulo',
'VTLIB_LBL_REQ_VTIGER_VERSION'=>'Req. Versão vtiger',
'VTLIB_LBL_LICENSE'=>'Licença',
'VTLIB_LBL_LICENSE_ACCEPT_AGREEMENT'=>'Eu aceito os termos da Licença.',
'VTLIB_LBL_PROCEED_WITH_IMPORT'=>'Deseja prosseguir com a importação?',
'VTLIB_LBL_IMPORTING_MODULE_START'=>'Importando Módulo ...',
'VTLIB_LBL_WARNING'=>'Aviso',
'VTLIB_LBL_NOT_WRITEABLE'=>'não escrita',
'VTLIB_LBL_PACKAGE_VERSION'=>'Versão',

'LBL_UPGRADE'=>'Atualização',
'VTLIB_LBL_UPDATE_FAILURE'=>'Falha Atualização',
'VTLIB_LBL_MODULENAME_MISMATCH'=>'Nome Módulo incompatà­vel',
'VTLIB_LBL_TRY_AGAIN'=>'Tente Novamente',
'VTLIB_LBL_VERIFY_UPDATE_DETAILS'=>'Verifique Detalhes Atualização',
'VTLIB_LBL_PROCEED_WITH_UPDATE'=>'Deseja prosseguir com a Atualização?',
'VTLIB_LBL_UPDAING_MODULE_START'=>'Atualizando Módulo ...',
'VTLIB_LBL_EXISTS'=>'Existe',
'VTLIB_LBL_NOT_PRESENT'=>'Ausente',
'VTLIB_LBL_INST_VERSION'=>'Versão Instalada',
'VTLIB_LBL_MATCHES_PACKAGE_VERSION'=>'compatibilidade Versão Pacote',
'VTLIB_LBL_CANNOT_UPGRADE'=>'não é possível atualizar!',
// END

//User group fixes
'LBL_USERNAME_EXIST' => 'Um Usuário com o nome especificado já existe!',
'LBL_GROUPNAME_EXIST' => 'Um Grupo com o nome especificado já existe!',
'LBL_ROLENAME_EXIST' => 'Nome Função já existe',

//layout editor
'LBL_MOVE_FIELDS' => 'Mover Campos',
'NO_HIDDEN_FIELDS' => 'Nenhum Campo Oculto',
'LBL_RELATED_LIST' => 'Lista Relacionada',
'LBL_ADD_BLOCK' => 'Adicionar Bloco',
'HIDDEN_FIELDS' => 'Ocultar Campos',
'DOWN'=> 'Abaixo',
'UP'=> 'Acima',
'RIGHT' => 'Direito',
'LEFT' => 'Esquerdo',
'LBL_EDIT_PROPERTIES' => 'Editar Propriedades',
'LBL_MANDATORY_FIELD' => 'Campo Obrigatório',
'LBL_ACTIVE' => 'Ativo',
'LBL_QUICK_CREATE' => 'Criar Rápido',
'LBL_MASS_EDIT' => 'Editar em Massa',
'LBL_BLOCK_NAME' => 'Nome Bloco',
'AFTER' => 'Depois',
'ADD_BLOCK' => 'Adicionar Bloco',
'ARRANGE_RELATEDLIST' => 'Organizar Lista Relacionada',
'CUSTOMFIELD_MAPPING' => 'Mapear Campo Customizado',
'LBL_MAPPED_FIELDS' => 'Campos Mapeados',
'LEADS_CUSTOM_FIELD_MAPPING_DESCRIPTION' => 'Mapear campos customizados de Leads com Organizações, Contatos e Oportunidades',
'LEADS_CUSTOM_FIELD_MAPPING'=> 'Mapear Campos Customizados de Leads',
'LBL_CALENDER_CUSTOMFIELDS' => 'Campos Customizados da Agenda',
'LBL_CALENDER_CUSTOMFIELDS_DESCRIPTION' => 'você pode Criar Campos Customizados para Agenda',
'LBL_GO_BACK'=>'Voltar',

//Added fix for: 5418
'LBL_USE_PREFIX' => 'Utizar Prefixo',
'LBL_START_SEQ' => 'Iniciar Sequência',
'LBL_MODULE_NUMBERING' => 'Numeração Módulo',
'LBL_FAILED' => 'Falhou',
'LBL_DONE' => 'Concluído',
'LBL_IN_USE' => 'EM USO',
'LBL_MODULE_NUMBERING_FIX_MISSING' => 'Atualizar Sequência de Registros Faltantes Agora',

//Added for: 5473
'LBL_SHARING_ACCESS_HELPNOTE' => 'Depois que fizer modificações, pressione o botão Recalcular para aplicar as mudanças.',

//for customer portal extension module
'PORTAL_EXTENSION_DESCRIPTION'=>'Permite Configurar o Plugin do Portal do Cliente',
'LBL_CUSTOMER_PORTAL'=> 'Portal do Cliente',

'LBL_ADD_CUSTOMFIELD' => 'Adicionar Campo Customizado',

'ERR_INVALID_PROFILE_ID' => 'ID Perfil Inválido. Por favor, especifique um ID do Perfil válido.',

// Customization
'LBL_PUBLISHER' => 'Editor',
'LBL_PUBLISHED_ON' => 'Publicado em',
'LBL_LICENSE'   => 'Licença',
'LBL_EXTENSION_FILE_DOWNLOAD_FAILED' => 'Falha ao fazer o download do pacote de extensão!',
'LBL_DEFAULT'=>'Por padrão, as configurações da Organização SMTP, para o Servidor de Envio de Mensagens, estão configuradas para o Servidor od1.vtiger.com. Para evitar problemas com os filtros de spam no Servidor de Mensagens do ISP (Provedor) do destinatário, recomendamos implementar o que se segue.',
'LBL_OPTIONS1'=>'Enviar emails a partir do seu Servidor de Envio de Mensagens<br>
				- Digite os detalhes da Organização SMTP (Nome Servidor, Usuário, Senha) para a mesma Organização digitada no endereço do Remetente (DE:).',
'LBL_OPTIONS2'=>"Adicionar o Servidor od1.vtiger.com como um remetente autorizado para seu domínio.<br>
				- Se você preferir manter o Servidor do vtiger como Servidor de Envio de Mensagem, recomendamos que configure seu registro SPF (Sender Policy Framework) do domínio, para incluir o Servidor do vtiger como um rementente válido para seu domínio.
				  Para instruções adicionais sobre configuração do registro SPF, por gentileza, envie email para od-support@vtiger.com.",
'LBL_ALREADY_EXISTS' => 'Já Existe',
'LBL_EXTENSION_INCOMPATIBLE' => 'Extensão Incompatível',
'LBL_INSTALL' => 'Instalar',
'LBL_DEFAULT_SETTINGS_BUTTON_TITLE' => 'Restaurar Padrão',
'LBL_CONFIRM_DEFAULT_SETTINGS' => 'Tem certeza que deseja mudar os detalhes do Servidor para os valores padrões do Servidor',
'EXISTING_DEFAULT_VALUES' => 'Os detalhes do Servidor já estão configurados para os valores padrões',
'LBL_NOTE' => 'Nota:',
'LBL_HIDE' => 'Ocultar Detalhes',
'LBL_SHOW' => 'Mostrar Detalhes',
// END
'LBL_USER_ADDITION_INFO'=>"Para adicionar um novo Usuário, por favor clique sobre  
			   <span style='font-style:italic;color:blue;'>Menu Configurações-OD -> Admin On Demand -> Adicionar / Convidar Usuário </span>",

'LBL_READ_ONLY_ACCESS_MSG' => 'Acesso Somente Leitura',
'LBL_READ_WRITE_ACCESS_MSG' => 'Acesso Leitura-Escrita',

'LBL_DEFAULT_VALUE' => 'Valor Padrão',

'LBL_DESCRIPTION_Public: Read Only'=>'Usuários podem acessar outros Usuários com privilégio "Somente Leitura"',
'LBL_DESCRIPTION_Public: Read, Create/Edit'=>'Usuários podem acessar outros Usuários com privilégio "Ler, Criar/Editar"',
'LBL_DESCRIPTION_Public: Read, Create/Edit, Delete'=>'Usuários podem acessar outros Usuários com privilégio "Ler, Criar/Editar, Apagar"',

// For Dependency picklist
'LBL_PICKLIST_DEPENDENCY_SETUP' => 'Configuração Dependência Lista Opções',
'LBL_PICKLIST_DEPENDENCY_DESCRIPTION' => 'Configuração Dependência entre valores Lista Opções em cada módulo',

'Settings' => 'Configurações',
'LBL_ERR_TAX_LABEL_ALREADY_EXISTS' => 'Este imposto já está disponível.',
'LBL_ERR_SOME_TAX_LABELS_ALREADY_EXISTS' => 'Alguns rótulos de impostos já estão disponíveis, portanto não foram salvos.',
'LBL_EDIT_COMPANY_INFO' => "Para editar os detalhes da empresa, por favor, clique sobre o
			   <span style='font-style:italic;color:blue;'>Ícone Configurações > Admin On Demand > Empresa </span>",

'Configuration Editor'=>'Editor Configuração',

'ModTracker' => 'Rastreador de Módulo',
'LBL_MODTRACKER_DESCRIPTION' => 'Selecionar Módulos para rastrear',

'LBL_MENUS_TO_SHOW'=>'Selecionar os Módulos para serem apresentados no menu principal',
'LBL_MENU_DESC'=>'Customizar sequência do Menu',
'LBL_MENU_EDITOR'=>'Editor de Menu',
'LBL_MENUS_TO_SHOW_DESCRIPTION' => 'Você pode utilizar as setas para ordenar os itens do Menu. Os 10 primeiros itens aparecem no menu principal e os demais são apresentados no dropdown <b><i>Mais</i></b>',
'LBL_ALL_MODULES' => 'Todos os Módulos',
'LBL_SELECTED_MODULES' => 'Módulos Selecionados',

'LBL_CRM_SETTINGS' => 'Configurações CRM',

//Fields missing vtiger CRM
'Add New'=> 'Adicionar Novo', // Added by Valmir Carlos Trindade - valmir@ttcasolucoes.com.br
'SMSNotifier'=>'Notificador SMS', // Added by Valmir Carlos Trindade - valmir@ttcasolucoes.com.br
);
?>
